@@ -22,8 +22,9 @@ var NAVTREEINDEX0 =
 "changelog.html#log_1_12":[31,1],
 "changelog.html#log_1_12_0":[31,1,0],
 "changelog.html#log_1_13":[31,0],
-"changelog.html#log_1_13_0":[31,0,1],
-"changelog.html#log_1_13_1":[31,0,0],
+"changelog.html#log_1_13_0":[31,0,2],
+"changelog.html#log_1_13_1":[31,0,1],
+"changelog.html#log_1_13_2":[31,0,0],
 "changelog.html#log_1_2":[31,11],
 "changelog.html#log_1_3":[31,10],
 "changelog.html#log_1_4":[31,9],
@@ -248,6 +249,5 @@ var NAVTREEINDEX0 =
 "commands.html#cmdretval":[24,113],
 "commands.html#cmdrtfinclude":[24,156],
 "commands.html#cmdrtfonly":[24,205],
-"commands.html#cmdsa":[24,114],
-"commands.html#cmdsecreflist":[24,132]
+"commands.html#cmdsa":[24,114]
 };
